import 'core-js/es/object/from-entries';
import 'core-js/es/string/match-all';
import 'core-js/es/promise/with-resolvers';
export declare enum BodyRequestMethods {
    POST = "POST",
    PUT = "PUT",
    PATCH = "PATCH",
    DELETE = "DELETE"
}
export interface RequestOptions {
    withCredentials?: boolean;
    timeout?: number;
    responseType?: XMLHttpRequestResponseType;
}
export interface Request extends RequestOptions {
    method?: 'HEAD' | 'GET' | keyof typeof BodyRequestMethods;
    path: string | URL;
    headers?: HeadersInit;
    body?: BodyInit | HTMLFormElement | any;
    signal?: AbortSignal;
}
export interface Response<B = Request['body']> {
    status: number;
    statusText: string;
    headers: Record<string, string | object>;
    body?: B;
}
export declare class HTTPError<B = Request['body']> extends URIError {
    request: Request;
    response: Response<B>;
    constructor(message: string, request: Request, response: Response<B>);
}
export type LinkHeader = Record<string, {
    URI: string;
    rel: string;
    title?: string;
}>;
export declare const headerParser: {
    Link: (value: string) => LinkHeader;
};
export declare const parseHeaders: (raw: string) => Response["headers"];
export declare function parseBody<T>(raw: string, contentType: string): T;
export declare function requestXHR<B>({ method, path, headers, body, signal, ...rest }: Request): Promise<{
    body: B;
    status: number;
    statusText: string;
    headers: Record<string, string | object>;
}>;
export declare function requestFetch<B>({ path, method, headers, withCredentials, body, signal, timeout, responseType }: Request): Promise<{
    status: number;
    statusText: string;
    headers: Record<string, string | object>;
    body: Awaited<B>;
}>;
export declare function parseFetchBody<B>(response: globalThis.Response, contentType: string, responseType: Request['responseType']): Promise<B>;
export declare const request: <B>(options: Request) => Promise<{
    body: B;
    status: number;
    statusText: string;
    headers: Record<string, string | object>;
}>;
